pub struct getStatementDataCall {
pub uid: FixedBytes<32>,
}Expand description
Function with signature getStatementData(bytes32) and selector 0xc75c572b.
function getStatementData(bytes32 uid) external view returns (StatementData memory);Fields
uid: FixedBytes<32>Trait Implementations
Sourceimpl Clone for getStatementDataCall
impl Clone for getStatementDataCall
Sourcefn clone(&self) -> getStatementDataCall
fn clone(&self) -> getStatementDataCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getStatementDataCall
impl Debug for getStatementDataCall
Sourceimpl SolCall for getStatementDataCall
impl SolCall for getStatementDataCall
Sourcetype Parameters<'a> = (FixedBytes<32>,)
type Parameters<'a> = (FixedBytes<32>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getStatementDataCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getStatementDataCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = getStatementDataReturn
type Return = getStatementDataReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (StatementData,)
type ReturnTuple<'a> = (StatementData,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getStatementDataCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getStatementDataCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.