pub struct makeStatementCall {
pub data: <StatementData as SolType>::RustType,
pub refUID: FixedBytes<32>,
}Expand description
Function with signature makeStatement((string),bytes32) and selector 0x455577cc.
function makeStatement(StatementData memory data, bytes32 refUID) external returns (bytes32 uid_);Fields
data: <StatementData as SolType>::RustTyperefUID: FixedBytes<32>Trait Implementations
Sourceimpl Clone for makeStatementCall
impl Clone for makeStatementCall
Sourcefn clone(&self) -> makeStatementCall
fn clone(&self) -> makeStatementCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for makeStatementCall
impl Debug for makeStatementCall
Sourceimpl SolCall for makeStatementCall
impl SolCall for makeStatementCall
Sourceconst SIGNATURE: &'static str = "makeStatement((string),bytes32)"
const SIGNATURE: &'static str = "makeStatement((string),bytes32)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (StatementData, FixedBytes<32>)
type Parameters<'a> = (StatementData, FixedBytes<32>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<makeStatementCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<makeStatementCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = makeStatementReturn
type Return = makeStatementReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (FixedBytes<32>,)
type ReturnTuple<'a> = (FixedBytes<32>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<makeStatementCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<makeStatementCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.