pub struct multiRevokeCall {
pub attestations: Vec<<Attestation as SolType>::RustType>,
pub values: Vec<U256>,
}Expand description
Function with signature multiRevoke((bytes32,bytes32,uint64,uint64,uint64,bytes32,address,address,bool,bytes)[],uint256[]) and selector 0x88e5b2d9.
function multiRevoke(Attestation[] memory attestations, uint256[] memory values) external payable returns (bool);Fields
attestations: Vec<<Attestation as SolType>::RustType>values: Vec<U256>Trait Implementations
Sourceimpl Clone for multiRevokeCall
impl Clone for multiRevokeCall
Sourcefn clone(&self) -> multiRevokeCall
fn clone(&self) -> multiRevokeCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for multiRevokeCall
impl Debug for multiRevokeCall
Sourceimpl SolCall for multiRevokeCall
impl SolCall for multiRevokeCall
Sourceconst SIGNATURE: &'static str = "multiRevoke((bytes32,bytes32,uint64,uint64,uint64,bytes32,address,address,bool,bytes)[],uint256[])"
const SIGNATURE: &'static str = "multiRevoke((bytes32,bytes32,uint64,uint64,uint64,bytes32,address,address,bool,bytes)[],uint256[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Array<Attestation>, Array<Uint<256>>)
type Parameters<'a> = (Array<Attestation>, Array<Uint<256>>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<multiRevokeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<multiRevokeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = multiRevokeReturn
type Return = multiRevokeReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<multiRevokeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<multiRevokeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.